unit_to_inch: Convert a measurement to inches based on the unit
Description
Convert a measurement to inches based on the unit
Usage
unit_to_inch(val, unit, dpi = 150)
Value
The measurement converted to inches
Arguments
- val
The measurement value
- unit
The unit of the measurement (e.g., "px", "mm", "cm", "in")
- dpi
The resolution to use when interpreting pixel units